#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from __future__ import absolute_import
from mastercardapicore import BaseObject
from mastercardapicore import RequestMap
from mastercardapicore import OperationConfig
from mastercardapicore import OperationMetadata
from mastercardp2m import ResourceConfig

class TransferNotificationRegistration(BaseObject):
    """
    
    """

    __config = {
        
        "809e5a71-76a8-4765-bdc6-95e0f5c20d2c" : OperationConfig("/send/v1/partners/{partnerId}/notification-registries/pan", "create", [], []),
        
        "6c0ae72d-da6a-4542-853c-53787a3f425e" : OperationConfig("/send/v1/partners/{partnerId}/notification-registries/pan ", "create", [], []),
        
        "7e79e1af-001b-47d5-a20b-aa8d1c572f47" : OperationConfig("/send/v1/partners/{partnerId}/notification-registries/readbypan", "create", [], []),
        
        "a0b978ca-04f4-45ac-a0c1-c4bbd4a42a8c" : OperationConfig("/send/v1/partners/{partnerId}/notification-registries/pan", "update", [], []),
        
    }

    def getOperationConfig(self,operationUUID):
        if operationUUID not in self.__config:
            raise Exception("Invalid operationUUID: "+operationUUID)

        return self.__config[operationUUID]

    def getOperationMetadata(self):
        return OperationMetadata(ResourceConfig.getInstance().getVersion(), ResourceConfig.getInstance().getHost(), ResourceConfig.getInstance().getContext(), ResourceConfig.getInstance().getJsonNative(), ResourceConfig.getInstance().getContentTypeOverride())


    @classmethod
    def create(cls,mapObj):
        """
        Creates object of type TransferNotificationRegistration

        @param Dict mapObj, containing the required parameters to create a new object
        @return TransferNotificationRegistration of the response of created instance.
        @raise ApiException: raised an exception from the response status
        """
        return BaseObject.execute("809e5a71-76a8-4765-bdc6-95e0f5c20d2c", TransferNotificationRegistration(mapObj))






    @classmethod
    def delete(cls,mapObj):
        """
        Creates object of type TransferNotificationRegistration

        @param Dict mapObj, containing the required parameters to create a new object
        @return TransferNotificationRegistration of the response of created instance.
        @raise ApiException: raised an exception from the response status
        """
        return BaseObject.execute("6c0ae72d-da6a-4542-853c-53787a3f425e", TransferNotificationRegistration(mapObj))






    @classmethod
    def readby(cls,mapObj):
        """
        Creates object of type TransferNotificationRegistration

        @param Dict mapObj, containing the required parameters to create a new object
        @return TransferNotificationRegistration of the response of created instance.
        @raise ApiException: raised an exception from the response status
        """
        return BaseObject.execute("7e79e1af-001b-47d5-a20b-aa8d1c572f47", TransferNotificationRegistration(mapObj))







    def update(self):
        """
        Updates an object of type TransferNotificationRegistration

        @return TransferNotificationRegistration object representing the response.
        @raise ApiException: raised an exception from the response status
        """
        return BaseObject.execute("a0b978ca-04f4-45ac-a0c1-c4bbd4a42a8c", self)






